@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2009 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "slicer-jigsaw.h"
 
@@ -83,7 +71,7 @@ JigsawPlugParams JigsawPlugParams::mirrored()
 	return result;
 }
 
-K_PLUGIN_FACTORY(SvgSlicerFactory, registerPlugin<JigsawSlicer>();)
+K_PLUGIN_CLASS_WITH_JSON(JigsawSlicer, "palapeli_jigsawslicer.json")
 
 JigsawSlicer::JigsawSlicer(QObject* parent, const QVariantList& args)
 	: Pala::Slicer(parent, args)
@@ -270,4 +258,5 @@ void JigsawSlicer::addPlugToPath(QPainterPath& path, qreal plugNormLength, const
 	path.cubicTo(r4, q5, p5);
 }
 
+#include "moc_slicer-jigsaw.cpp"
 #include "slicer-jigsaw.moc"
