@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "constraintvisualizer.h"
 #include "scene.h"
@@ -89,7 +77,7 @@ void Palapeli::ConstraintVisualizer::stop()
 		return;		// Starting first loadPuzzle(): nothing to do.
 	}
 	m_scene->removeItem(this);
-	disconnect(m_scene, SIGNAL(sceneRectChanged(QRectF)));
+	disconnect(m_scene, &QGraphicsScene::sceneRectChanged, this, &ConstraintVisualizer::update);
 	m_sceneRect = QRectF();
 	m_isStopped = true;
 }
@@ -183,4 +171,4 @@ void Palapeli::ConstraintVisualizer::update(const QRectF& sceneRect)
 	m_handleItems[RightHandle]->setRect(handleRect);
 }
 
-
+#include "moc_constraintvisualizer.cpp"
