@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2009-2011 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009-2011 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "components.h"
 
@@ -33,7 +21,7 @@ Palapeli::PuzzleComponent* Palapeli::ArchiveStorageComponent::cast(Palapeli::Puz
 		//open archive and extract into temporary directory
 		KTar tar(puzzle()->location(), QStringLiteral("application/x-gzip"));
 		if (!tar.open(QIODevice::ReadOnly))
-			return 0;
+			return nullptr;
 		Palapeli::DirectoryStorageComponent* storage = new Palapeli::DirectoryStorageComponent;
 		tar.directory()->copyTo(storage->directory());
 		//cleanup
@@ -43,22 +31,22 @@ Palapeli::PuzzleComponent* Palapeli::ArchiveStorageComponent::cast(Palapeli::Puz
 	else
 	{
 		const Palapeli::PuzzleComponent* dirStorage = puzzle()->get(DirectoryStorage);
-		return dirStorage ? dirStorage->cast(type) : 0;
+		return dirStorage ? dirStorage->cast(type) : nullptr;
 	}
 }
 
 Palapeli::ArchiveStorageComponent* Palapeli::ArchiveStorageComponent::fromData(Palapeli::Puzzle* puzzle)
 {
-	puzzle->get(DirectoryStorage).waitForFinished();
+	puzzle->get(DirectoryStorage);
 	const Palapeli::DirectoryStorageComponent* dirStorage = puzzle->component<Palapeli::DirectoryStorageComponent>();
 	//compress archive to location
 	KTar tar(puzzle->location(), QStringLiteral("application/x-gzip"));
 	if (!tar.open(QIODevice::WriteOnly))
-		return 0;
+		return nullptr;
 	if (!tar.addLocalDirectory(dirStorage->directory(), QStringLiteral(".")))
-		return 0;
+		return nullptr;
 	if (!tar.close())
-		return 0;
+		return nullptr;
 	//done
 	return new Palapeli::ArchiveStorageComponent;
 }
