@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2014 Ian Wadham <iandw.au@gmail.com>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014 Ian Wadham <iandw.au@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef PALAPELI_PIECEHOLDER_H
 #define PALAPELI_PIECEHOLDER_H
@@ -51,8 +39,8 @@ namespace Palapeli
 			void setSelected(bool onOff);
 			QString name() { return windowTitle(); }
 		protected:
-			void focusInEvent(QFocusEvent* e) Q_DECL_OVERRIDE;
-			void closeEvent(QCloseEvent* event) Q_DECL_OVERRIDE;
+			void focusInEvent(QFocusEvent* e) override;
+			void closeEvent(QCloseEvent* event) override;
 		Q_SIGNALS:
 			void selected(PieceHolder* h);
 			void closing(PieceHolder* h);
